#!/usr/bin/env python

import os,glob
from setuptools import setup,find_packages

VERSION='3.2'

setup(
    name = 'musa',
    version = VERSION,
    license = 'PSF',
    author = 'Ilkka Tuohela',
    author_email = 'hile@iki.fi',
    description = 'Module for music tagging and library management',
    long_description = open(os.path.join(os.path.dirname(__file__),'README.md'),'r').read(),
    keywords = 'music library tag management',
    url = 'http://tuohela.net/packages/musa',
    zip_safe = False,
    packages = ( 'musa', ),
    package_data = { '': [ '*.md', '*.txt' ] },
    scripts = glob.glob('bin/*'),
    install_requires = ( 
        'configobj', 
        'soundforest>=3.2', 
    ),
)





import os,re
import unittest

from musa.models import Codec
from musa.config import MusaConfigDB
from musa.formats import MusaFileFormat,filter_available_command_list,match_codec


class test_codecs(unittest.TestCase):
    def test_codec_config_keys(self):
        db = MusaConfigDB()
        for k in db.codecs.keys():
            self.assertIsInstance(match_codec(k),Codec)
            self.assertEquals(k,match_codec(k).name)

        for k,v in db.codecs.items():
            if 'extensions' not in v.extensions:
                continue
            for ext in v['extensions']:
                self.assertEquals(k,match_codec(ext).name)

    def test_fileformat_loader(self):
        db = MusaConfigDB()
        for k in db.codecs.keys():
            testpath = os.path.join('/tmp/test.%s' % k)
            musaformat = MusaFileFormat(testpath)
            self.assertEquals(k,musaformat.codec.name)
            self.assertIsInstance(musaformat.get_available_encoders(),list)
            self.assertIsInstance(musaformat.get_available_decoders(),list)

        self.assertEquals(MusaFileFormat('/etc/passwd').codec,None)


suite = unittest.TestLoader().loadTestsFromTestCase(test_codecs)
